Documentation
¶
Overview ¶
Package jwt manipulates JWT tokens.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateFromCert ¶
func CreateFromCert(svcName string, caPEM []byte, cert *x509.Certificate, trustedHost bool) (string, error)
CreateFromCert a JWT whose content indicate a high-trust login.
Types ¶
type ServiceClaims ¶
type ServiceClaims struct {
// Email is the actor who is logging in.
Email string
// Target defines to which service this token was created for.
Target string
// Trust defines the trust level so to give the application some context
// on how it should handle low-trust logins.
Trust string
jwt.StandardClaims
}
ServiceClaims define the set of claims used by cirello.io services.
Click to show internal directories.
Click to hide internal directories.